pub struct TargetShapeFilter(/* private fields */);Expand description
Bitmask that specifies what shapes are targeted by an action.
Implementations
Sourceimpl TargetShapeFilter
impl TargetShapeFilter
Sourcepub const NONE: TargetShapeFilter
pub const NONE: TargetShapeFilter
Match no shapes.
Sourcepub const ALL: TargetShapeFilter
pub const ALL: TargetShapeFilter
Match all shapes.
Sourcepub const CHAR: TargetShapeFilter
pub const CHAR: TargetShapeFilter
Match TargetShape::CharWise.
Sourcepub const LINE: TargetShapeFilter
pub const LINE: TargetShapeFilter
Match TargetShape::LineWise.
Sourcepub const BLOCK: TargetShapeFilter
pub const BLOCK: TargetShapeFilter
Match TargetShape::BlockWise.
Sourceimpl TargetShapeFilter
impl TargetShapeFilter
Sourcepub const fn empty() -> TargetShapeFilter
pub const fn empty() -> TargetShapeFilter
Get a flags value with all bits unset.
Sourcepub const fn all() -> TargetShapeFilter
pub const fn all() -> TargetShapeFilter
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<TargetShapeFilter>
pub const fn from_bits(bits: u32) -> Option<TargetShapeFilter>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> TargetShapeFilter
pub const fn from_bits_truncate(bits: u32) -> TargetShapeFilter
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> TargetShapeFilter
pub const fn from_bits_retain(bits: u32) -> TargetShapeFilter
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<TargetShapeFilter>
pub fn from_name(name: &str) -> Option<TargetShapeFilter>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: TargetShapeFilter) -> bool
pub const fn intersects(&self, other: TargetShapeFilter) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: TargetShapeFilter) -> bool
pub const fn contains(&self, other: TargetShapeFilter) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: TargetShapeFilter)
pub fn insert(&mut self, other: TargetShapeFilter)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: TargetShapeFilter)
pub fn remove(&mut self, other: TargetShapeFilter)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: TargetShapeFilter)
pub fn toggle(&mut self, other: TargetShapeFilter)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: TargetShapeFilter, value: bool)
pub fn set(&mut self, other: TargetShapeFilter, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: TargetShapeFilter) -> TargetShapeFilter
pub const fn intersection(self, other: TargetShapeFilter) -> TargetShapeFilter
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: TargetShapeFilter) -> TargetShapeFilter
pub const fn union(self, other: TargetShapeFilter) -> TargetShapeFilter
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: TargetShapeFilter) -> TargetShapeFilter
pub const fn difference(self, other: TargetShapeFilter) -> TargetShapeFilter
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: TargetShapeFilter,
) -> TargetShapeFilter
pub const fn symmetric_difference( self, other: TargetShapeFilter, ) -> TargetShapeFilter
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> TargetShapeFilter
pub const fn complement(self) -> TargetShapeFilter
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl TargetShapeFilter
impl TargetShapeFilter
Sourcepub const fn iter(&self) -> Iter<TargetShapeFilter>
pub const fn iter(&self) -> Iter<TargetShapeFilter>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<TargetShapeFilter>
pub const fn iter_names(&self) -> IterNames<TargetShapeFilter>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl TargetShapeFilter
impl TargetShapeFilter
Sourcepub fn matches(&self, shape: &TargetShape) -> bool
pub fn matches(&self, shape: &TargetShape) -> bool
Check whether this filter applies to a given TargetShape.