pub struct TerminalKey { /* private fields */ }Expand description
A key pressed in a terminal.
It’s important to remember when setting up keybindings and building a TUI that some terminals represent several keypresses the same way by default, while others are capable of precisely representing what keys the user actually pressed, such as when using something like crossterm::event::PushKeyboardEnhancementFlags or when running in Windows terminal.
For example, if you’re using crossterm::event::KeyCode then you’ll likely run into the following in a Unix terminal:
<C-M>will sometimes be represented as<Enter><C-I>will sometimes be represented as<Tab><C-?>will sometimes be represented as<BackSpace><C-@>will sometimes be represented as<C-Space><C-[>will sometimes be represented as<Esc><C-\>will sometimes be represented as<C-4><C-]>will sometimes be represented as<C-5><C-^>will sometimes be represented as<C-6><C-_>will sometimes be represented as<C-7>
You can avoid getting bit by differences between terminals by mapping all of these to the same action for consistency.
Additionally, some modifier keys can’t be expressed by default: <S-Enter> or <C-Enter>
cannot always be represented. If you map those, make sure you also provide alternatives!
Implementations
Sourceimpl TerminalKey
impl TerminalKey
Sourcepub fn get_literal_char(&self) -> Option<char>
pub fn get_literal_char(&self) -> Option<char>
Return this key’s representation as a single codepoint, if it exists.